<?php

namespace CSPro\User;

use Silex\Application;
use CSPro\User\User;

class UserParser {

    protected $passWordHashMap = array();

    function calculateHashCost($app) {
        $timeTarget = 0.001;

        $cost = 3;
        do {
            $cost++;
            $start = microtime(true);
            password_hash("test", PASSWORD_BCRYPT, ["cost" => $cost]);
            $end = microtime(true);
        } while (($end - $start) < $timeTarget);

        $app ['monolog']->addDebug("Appropriate Cost Found: " . $cost);
    }

    // transform the users
    function transformUser($user) {

        if ($user->getRole() == "Standard User") {
            $user->setRole(1);
        } else if ($user->getRole() == "Administrator") {
            $user->setRole(2);
        }

        $options = [
            'cost' => 8
        ];

        if (!isset($this->passWordHashMap[$user->getPassword()])) {//if hash not found create and store
            $passwordHash = password_hash($user->getPassword(), PASSWORD_BCRYPT, $options);
            $this->passWordHashMap[$user->getPassword()] = $passwordHash;
            $user->setPassword($passwordHash);
        } else {//use the stored hash
            $passwordHash = $this->passWordHashMap[$user->getPassword()];
            $user->setPassword($passwordHash);
        }

        return $user;
    }

    // parse and transform users, return users array
    function parseUsers($app, $content, $headerRow) {
        $maxUsers = $app['maxUsersImport'];

        $users = array();
        $csv = array();

        $lines = explode("\n", $content);
        $lineCount = count($lines);
        $startLine = 0;
        if($headerRow === true) {
            $startLine = 1;
            $app['monolog']->addDebug("Ignoring header row");
        }
            
        // why "maxUsers + 1" you say? Apparently an extra line is added during the above explode() call.
        if ($lineCount > $maxUsers + 1)
            throw new \Exception("The maximum allowable number of users to be created has been exceeded. There is a limit of " . $maxUsers . " users that can be created at one time. Please break the file into smaller files and proceed.", 0);

        for ($i = $startLine; $i < $lineCount; $i++) {

            $csv = str_getcsv($lines[$i], ",", '"', "\n");
             //set the user attributes to null if they are not set
            for ($attrIndex = 0; $attrIndex < 7; $attrIndex++) {
                if(!isset($csv[$attrIndex])) 
                     $csv[$attrIndex] = null;
            }

            if ($csv[0] != null) {
                if(empty(trim($csv[5]))) $csv[5] = null; //email
                if(empty(trim($csv[6]))) $csv[6] = null; //phone
               
                $user = new User($csv[0], $csv[1], $csv[2], $csv[3], $csv[4],$csv[5], $csv[6]);
                array_push($users, $user);
            } else {
                break;
            }
        }

        return $users;
    }

}
