<?php

namespace Controllers;

use Silex\Application;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Exception\ResourceNotFoundException;
use Silex\ControllerProviderInterface;

class UserController implements ControllerProviderInterface {

    public function connect(Application $app) {
        // creates a new controller based on the default route
        $controllers = $app['controllers_factory'];
        $controllers->get('/', 'Controllers\UserController::viewUserListAction')->bind('users');
        $controllers->get('/json', 'Controllers\UserController::viewUserListJson')->bind('usersJson');
        $controllers->post('/', 'Controllers\UserController::addUserAction')->bind('add');
        $controllers->put('/{username}', 'Controllers\UserController::updateUserAction')->bind('update');
        $controllers->delete('/{username}', 'Controllers\UserController::deleteAction')->bind('delete');
        $controllers->before(function(Request $request, Application $app) {
            $accesss_token = "";
            if (!$app['request']->cookies->has('access_token')) {
                return $app->redirect($app["url_generator"]->generate('login'));
            }
        });
        return $controllers;
    }

    public function viewUserListAction(Application $app) {
        //TODO: refactor
        /* $client = $app['services.httphelper'] ;
          //set the oauth token
          $access_token = $app['request']->cookies->has('access_token') ? $app['request']->cookies->get('access_token')  :  "" ;
          $authHeader = 'Bearer ' .  $access_token;
          $response = $client->request('GET','users', null, ['Authorization' =>$authHeader,'Accept' => 'application/json']);

          //unauthorized or expired  redirect to logout page
          if($response->getStatusCode() == 401) {
          return $app->redirect($app["url_generator"]->generate('logout'));
          }
          $userlist=json_decode($response->getBody()); */
        return $app['twig']->render('users.twig');

        //return $app['twig']->render('users.twig', array('userlist' => $userlist));
    }

    public function viewUserListJson(Application $app) {
        // set client
        $client = $app['services.httphelper'];

        //set the oauth token
        $access_token = $app['request']->cookies->has('access_token') ? $app['request']->cookies->get('access_token') : "";

        $start = $app['request']->get('start');
        $length = $app['request']->get('length');
        $draw = (int) $app['request']->get('draw');
        $search = $app['request']->get('search');
        $order = $app['request']->get('order');
        $orderColumn = $order[0]['column'];
        $orderDirection = $order[0]['dir'];

        // set authorization header
        $authHeader = 'Bearer ' . $access_token;

        $apiResponse = $client->request('GET', 'users', null, ['Authorization' => $authHeader,
            'Accept' => 'application/json',
            'x-csw-user-start' => $start,
            'x-csw-user-length' => $length,
            'x-csw-user-search' => $search['value'],
            'x-csw-user-order-column' => $orderColumn,
            'x-csw-user-order-direction' => $orderDirection
        ]);

        //unauthorized or expired  redirect to logout page
        if ($apiResponse->getStatusCode() == 401) {
            return $app->redirect($app["url_generator"]->generate('logout'));
        }
        $headers = $apiResponse->getHeaders();
        $userCount = 0;
        $usersFiltered = 0;

        //user count
        if (array_key_exists('x-csw-user-count', $headers)) {
            $temp = $headers['x-csw-user-count'];
            $userCount = $temp[0];
        } else
            $userCount = 0;

        //users filtered
        if (array_key_exists('x-csw-users-filtered', $headers)) {
            $temp = $headers['x-csw-users-filtered'];
            $usersFiltered = $temp[0];
        } else
            $usersFiltered = 0;

        $userlist = json_decode($apiResponse->getBody());

        $result = array("data" => $userlist, "draw" => $draw, "recordsTotal" => $userCount, "recordsFiltered" => $usersFiltered);

        $response = new Response(json_encode($result));
        $response->headers->set('Content-Length', strlen($response->getContent()));
        return $response;
    }

    public function addUserAction(Application $app, Request $request) {

        ini_set('max_execution_time', 420); //300 seconds = 5 minutes

        $client = $app['services.httphelper'];
        //set the oauth token
        $access_token = $app['request']->cookies->has('access_token') ? $app['request']->cookies->get('access_token') : "";
        $authHeader = 'Bearer ' . $access_token;

        //get the json user info to add
        $body = $request->getContent();

        //call the rest api to  add the user	    
        $response = $client->request('POST', 'users/', $body, ['Authorization' => $authHeader, 'Content-Type' => 'application/json; charset=utf-8', 'Accept' => 'application/json', 'Time-Stamp' => $request->headers->get("TIME-STAMP")]);                       //unauthorized or expired  redirect to logout page
        $app ['monolog']->addDebug('**********addUserAction-UI status-code: ' . $response->getStatusCode());
        if ($response->getStatusCode() == 401) {
            return $app->redirect($app["url_generator"]->generate('logout'));
        }
        //create a symfony response object to return
        $addUserResponse = new Response($response->getBody(), $response->getStatusCode());
        $addUserResponse->headers->set('Content-Type', $response->getHeader('Content-Type'));
        return $addUserResponse;
    }

    public function updateUserAction(Application $app, Request $request, $username) {
        $client = $app['services.httphelper'];

        //set the oauth token
        $access_token = $app['request']->cookies->has('access_token') ? $app['request']->cookies->get('access_token') : "";
        $authHeader = 'Bearer ' . $access_token;

        //get the json user info to update 
        $body = $request->getContent();
        //call the rest api to  update the user
        $response = $client->request('PUT', 'users/' . $username, $body, ['Authorization' => $authHeader]);

        //unauthorized or expired  redirect to logout page
        if ($response->getStatusCode() == 401) {
            return $app->redirect($app["url_generator"]->generate('logout'));
        }
        //create a symfony response object to return
        $updateUserResponse = new Response($response->getBody(), $response->getStatusCode());
        $updateUserResponse->headers->set('Content-Type', $response->getHeader('Content-Type'));
        return $updateUserResponse;
    }

    public function deleteAction(Application $app, $username) {
        $client = $app['services.httphelper'];
        //set the oauth token
        $access_token = $app['request']->cookies->has('access_token') ? $app['request']->cookies->get('access_token') : "";
        $authHeader = 'Bearer ' . $access_token;

        //call the rest-api to delete the user
        $response = $client->request('DELETE', 'users/' . $username, null, ['Authorization' => $authHeader, 'Accept' => 'application/json']);

        //unauthorized or expired  redirect to logout page
        if ($response->getStatusCode() == 401) {
            return $app->redirect($app["url_generator"]->generate('logout'));
        }
        //create the symfony response for the delete action
        $deleteResponse = new Response($response->getBody(), $response->getStatusCode());
        $deleteResponse->headers->set('Content-Type', $response->getHeader('Content-Type'));
        return $deleteResponse;
    }

}
