<?php  
require_once __DIR__ .'/../setup/util.php';
require_once getApiVersionFilePath();
?>

<!DOCTYPE html>
<html>
<head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta name="description" content="">
    <meta name="author" content="">

	<link rel='icon' href='../ui/dist/img/favicon.ico' type='image/x-icon'/ >
	
	<title>CSWeb: Upgrade</title>

    <!-- Bootstrap Core CSS -->
    <link href="../ui/bower_components/bootstrap/dist/css/bootstrap.min.css" rel="stylesheet">

    <!-- Custom Fonts -->
    <link href="../ui/bower_components/font-awesome/css/font-awesome.min.css" rel="stylesheet" type="text/css">

    <!-- HTML5 Shim and Respond.js IE8 support of HTML5 elements and media queries -->
    <!-- WARNING: Respond.js doesn't work if you view the page via file:// -->
    <!--[if lt IE 9]>
        <script src="https://oss.maxcdn.com/libs/html5shiv/3.7.0/html5shiv.js"></script>
        <script src="https://oss.maxcdn.com/libs/respond.js/1.4.2/respond.min.js"></script>
    <![endif]-->

</head>
<body>

<div class="container">
<div class="page-header">
<h1>CSWeb: Upgrade Database</h1>
</div>

<?php

    function schema1To2($pdo)
    {
		//apps table
		$sql = <<<'EOT'
			CREATE TABLE IF NOT EXISTS `cspro_apps` (
			  `id` int NOT NULL AUTO_INCREMENT PRIMARY KEY,
			  `name` varchar(128) COLLATE utf8mb4_unicode_ci NOT NULL,
			  `description` varchar(512) COLLATE utf8mb4_unicode_ci NOT NULL,
			  `build_time` datetime NOT NULL,
			  `path` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL,
			  `version` varchar(16) COLLATE utf8mb4_unicode_ci NOT NULL,
			  `modified_time` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
			  `created_time` timestamp DEFAULT '1971-01-01 00:00:00',
			  UNIQUE KEY `name` (`name`)
			) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;
			CREATE TRIGGER tr_cspro_apps BEFORE INSERT ON `cspro_apps` FOR EACH ROW SET NEW.`created_time` = CURRENT_TIMESTAMP;
EOT;
		$pdo->exec($sql);
		$sql = "UPDATE `cspro_config` SET `value`=2 where `name` = 'schema_version'";
		$pdo->exec($sql);
    }

    function schema2To3($pdo) {
    try {
        $addNewColumns = array("email", "phone");
        //add the email and phone columns to the user table and upgrade the schema version 
        //Read out actual columns
        $addedFields = array();
        $rs = $pdo->query('SELECT * FROM `cspro_users` LIMIT 0');
        for ($i = 0; $i < $rs->columnCount(); $i++) {
            $col = $rs->getColumnMeta($i);
            $colName = strtolower($col['name']);
            if (in_array($colName, $addNewColumns)) {
                $addedFields[] = $colName;
            }
        }
        $columnsToAdd = array_diff($addNewColumns, $addedFields);
        //Add columns
        if (!empty($columnsToAdd)) {
            foreach ($columnsToAdd as $c) {
                if (strcasecmp($c, "email") == 0) {
                    $pdo->exec('ALTER TABLE `cspro_users` add `' . $c . '` VARCHAR(255) NULL DEFAULT NULL AFTER `last_name`;');
                } else if (strcasecmp($c, "phone") == 0) {
                    $pdo->exec('ALTER TABLE `cspro_users` add `' . $c . '` VARCHAR(50) NULL DEFAULT NULL AFTER `email`;');
                }
            }
        }
        //update the schema version 
        $sql = "UPDATE `cspro_config` SET `value`=3 where `name` = 'schema_version'";
        $pdo->exec($sql);
    } catch (\Exception $e) {
        throw $e;
    }
}

$migrateFuncs = array( 
        1 => 'schema1To2',
        2 => 'schema2To3'
    );

    // Check if app was already configured
    if (!alreadyConfigured()) {
        echo 'This application has not yet been configured. Click <a href="../setup/">here</a> to configure it.';
    } else {
        require_once getApiConfigFilePath();

        try {

           // Create database connection
            $pdo = new PDO('mysql:host='.DBHOST.';dbname='.DBNAME.';charset=utf8mb4', 
                            DBUSER, DBPASS, array(PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION));

            // Get current schema version
		    $dbSchemaVersion = $pdo->query("SELECT `value` FROM `cspro_config` WHERE `name`='schema_version'")->fetchColumn();

            while ($dbSchemaVersion < SCHEMA_VERSION)
            {
                echo '<p>Upgrading to version ' . ($dbSchemaVersion + 1) . '...';
                $migrateFunc = $migrateFuncs[$dbSchemaVersion];
                call_user_func($migrateFunc, $pdo);
                echo ' Done</p>';
               ++$dbSchemaVersion;
            }

            echo '<br/>';
            echo '<div class="alert alert-success" role="alert">Database Upgrade Complete!</div>';
            echo '<a href="../ui/" class="btn btn-primary pull-right">Login</a>';

        } catch (Exception $e) {
            echo '<div class="alert alert-danger" role="alert">Error: ' . $e->getMessage() . '</div>';
        }
    }
?>

</div>
</body>
</html>